@@ -10,8 +10,8 @@
 
 struct Builtin: public BuiltinFunctions
 {
-    typedef std::initializer_list<ExprType> Args;   // argument types
-    typedef Args::const_iterator ArgsIter; 
+    using Args = std::initializer_list<ExprType>;   // argument types
+    using ArgsIter =  Args::const_iterator;
 
     private:
         struct Info                                 // Builtin function info:
